@@ -1,5 +1,5 @@
 from .mathtable import MathTable
 from .styles import styledchr, styledstr
-from .zmath import Math
+from .zmath import Math, Text, set_precision
 
-__version__ = '0.4'
\ No newline at end of file
+__version__ = '0.5'
\ No newline at end of file
